<?php
/**
 * Functions  Template
 *
 * @package Orbit
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 */
function orbit_setup() {
	global $content_width;

	// Global content width.
	if ( !isset($content_width) )
		$content_width = 540;

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	//	For translation/localization support.
	load_theme_textdomain( 'orbit', get_template_directory() .'/languages' );

	// Add callback for custom TinyMCE editor stylesheets. (editor-style.css)
	add_editor_style();

	// Load up our theme options page and related code.
	require( get_template_directory() . '/inc/theme-options.php' );

	// Load up our theme options to custom style.
	require( get_template_directory() . '/inc/insert-options.php' );

	// Load up our theme hooks.
	require( get_template_directory() . '/inc/hooks.php' );

	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// Add support for custom backgrounds.
	add_theme_support( 'custom-background', array( 'default-color' => 'f6f6f6',) );

	add_theme_support( 'custom-header', array (
	   'default-image'			=> get_template_directory_uri() . '/images/default-logo.png',		// Header image default
	   'header-text'			=> false,															// Header text display default
	   'flex-width'				=> true,															// Header image flex width
	   'width'					=> 240,																// Header image width (in pixels)
	   'flex-height'			=> true,															// Header image flex height
	   'height'					=> 72 ) );															// Header image height (in pixels)

	// Header menu
	register_nav_menu( 'header-menu', __( 'Header Menu', 'orbit' ) );

	// Footer menu
	register_nav_menu( 'footer-menu', __( 'Footer Menu', 'orbit' ) );

}
add_action( 'after_setup_theme', 'orbit_setup' );

/**
 * Register our sidebars and widgetized areas.
 *
 */
function orbit_widgets_init() {

	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'orbit' ),
		'description' => __( 'Main sidebar - sidebar.php', 'orbit' ),
		'id' => 'main-sidebar',
		'before_widget' => '<div id="%1$s" class="aside-box %2$s">',
		'after_widget' => '</div> <!-- end widget aside-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	) );

	register_sidebar( array(
		'name' => __( 'Second Sidebar', 'orbit' ),
		'description' => __( 'Sidebar in template page-two.php - sidebar-two.php', 'orbit' ),
		'id' => 'second-sidebar',
		'before_widget' => '<div id="%1$s" class="aside-box %2$s">',
		'after_widget' => '</div> <!-- end widget aside-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	) );

	register_sidebar( array(
		'name' => __( 'Front Box 1', 'orbit' ),
		'description' => __( 'First box in front page - front-page.php', 'orbit' ),
		'id' => 'front-box-1',
		'before_widget' => '<div id="%1$s" class="widget-front-box %2$s">',
		'after_widget' => '</div> <!-- end widget-front-box -->',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));

	register_sidebar( array(
		'name' => __( 'Front Box 2', 'orbit' ),
		'description' => __( 'Second box in front page - front-page.php', 'orbit' ),
		'id' => 'front-box-2',
		'before_widget' => '<div id="%1$s" class="widget-front-box %2$s">',
		'after_widget' => '</div> <!-- end widget-front-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));

	register_sidebar( array(
		'name' => __( 'Front Box 3', 'orbit' ),
		'description' => __( 'Third box in front page - front-page.php', 'orbit' ),
		'id' => 'front-box-3',
		'before_widget' => '<div id="%1$s" class="widget-front-box %2$s">',
		'after_widget' => '</div> <!-- end widget-front-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));

	register_sidebar( array(
		'name' => __( 'Footer Box 1', 'orbit' ),
		'description' => __( 'First box in footer - footer.php', 'orbit' ),
		'id' => 'footer-box-1',
		'before_widget' => '<div id="%1$s" class="widget-footer-box %2$s">',
		'after_widget' => '</div> <!-- end widget-footer-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));

	register_sidebar( array(
		'name' => __( 'Footer Box 2', 'orbit' ),
		'description' => __( 'Second box in footer - footer.php', 'orbit' ),
		'id' => 'footer-box-2',
		'before_widget' => '<div id="%1$s" class="widget-footer-box %2$s">',
		'after_widget' => '</div> <!-- end widget-footer-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));

	register_sidebar( array(
		'name' => __( 'Footer Box 3', 'orbit' ),
		'description' => __( 'Third box in footer - footer.php', 'orbit' ),
		'id' => 'footer-box-3',
		'before_widget' => '<div id="%1$s" class="widget-footer-box %2$s">',
		'after_widget' => '</div> <!-- end widget-footer-box -->',
		'before_title' => '<h2 class="widget-title">',
		'after_title' => '</h2>',
	));
}
add_action( 'widgets_init', 'orbit_widgets_init' );

/**
 * A safe way of adding JavaScripts to a WordPress generated page.
 */
function orbit_script_enqueuer() {

	// Style for orbit theme
	wp_enqueue_style( 'orbit-style', get_stylesheet_uri() );

	// Fonts from google
	$orbit_options = orbit_get_theme_options();
	if ( $orbit_options['google_font_title'] != '' ) {
		wp_enqueue_style( 'FontTitle', '//fonts.googleapis.com/css?family=' . esc_attr( $orbit_options['google_font_title'] ) );
	}
	if ( $orbit_options['google_font_base']	 != '' ) {
		wp_enqueue_style( 'FontGeneral', '//fonts.googleapis.com/css?family=' . esc_attr( $orbit_options['google_font_base'] ) );
	}

	// Slider function by flexslider
	wp_enqueue_script( 'orbit-slider', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array( 'jquery' ), '', false);

	// Responsive menu by tinynav
	wp_enqueue_script( 'orbit-navigation', get_template_directory_uri() . '/js/tinynav.min.js', array( 'jquery' ), '0.1', false );

	// Comment reply function
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

}
add_action( 'wp_enqueue_scripts', 'orbit_script_enqueuer' );

/**
 * Replaces "[...]" in excerpts with "Read more"
 */
function orbit_remove_ellipsis_excerpts( $more ) {

	return '<p><a class="more-link" href="' . get_permalink() . '">' . __( 'Read more &#8250;', 'orbit' ) . '</a></p>';
}
add_filter( 'excerpt_more', 'orbit_remove_ellipsis_excerpts' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function orbit_add_home_link_menu( $args ) {

	$args['show_home'] = true;

	return $args;
}
add_filter( 'wp_page_menu_args', 'orbit_add_home_link_menu' );


/**
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 */
function orbit_wp_title( $title, $sep ) {
	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	return $title;
}
add_filter( 'wp_title', 'orbit_wp_title', 10, 2 );


function orbit_favicon() {
	$options = orbit_get_theme_options();
	if ( $options['favicon'] != '' )
		echo '<link rel="icon" href="' . $options['favicon'] . '" type="image/x-icon" />';
}
add_action('wp_head', 'orbit_favicon');

/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own orbit_render_list_comments(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function orbit_render_list_comments( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	if ( $comment->comment_approved == '1' ): ?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<article id="comment-<?php comment_ID() ?>">
			<?php if ( $comment->comment_type == 'pingback' || $comment->comment_type == 'trackback' ): ?>
				<header class="header-comment">
					<h3><?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'orbit' ), '<span class="edit-link"> | ', '</span>' ); ?> </h3>
				</header>
			<?php else: ?>
				<header class="header-comment">
					<div class="comment-avatar">
						<?php echo get_avatar( $comment, 42 ); ?>
					</div>
					<div class="comment-text">
						<h3><?php comment_author_link() ?></h3>
						<p><?php printf( '<time datetime="%1$s">%2$s %3$s %4$s</time>',
									get_comment_time( 'c' ), get_comment_date(), __( 'at', 'orbit' ), get_comment_time() ); ?> <?php edit_comment_link( __( 'Edit', 'orbit' ), '<span class="edit-link"> | ', '</span>' ); ?><?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'orbit' ), 'depth' => $depth, 'max_depth' => $args['max_depth'], 'before' => '<span class="edit-link"> | ', 'after' => '</span>' ) ) ); ?></p>
						<?php comment_text() ?>
					</div>
				</header>
			<?php endif ?>
			</article>
	<?php endif;
}

/**
 * Capture title from current menu item and set a global variable to
 * use in orbit_render_breadcrumb (ex. if you page for posts is different of "blog")
 */
function orbit_capture_title_page_for_breadcrumb( $sorted_menu_items )
{
	foreach ( $sorted_menu_items as $menu_item ) {
		if ( $menu_item->current ) {
			$GLOBALS['orbit_current_menu_title'] = $menu_item->title;
			break;
		}
	}
	return $sorted_menu_items;
}
add_filter( 'wp_nav_menu_objects', 'orbit_capture_title_page_for_breadcrumb' );

/**
 * Render Breadcrumb.
 */
function orbit_render_breadcrumb() {
	global $post;

	$chevron = '<span class="chevron">&#8250;</span>';
	$before = '<div class="breadcrumb"><p>';
	$options = orbit_get_theme_options();

	if ( ( $options['pagination'] == 'pages' )
		&& get_query_var( 'paged' )
		&& ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) ) {
			$after = ' ( ' . __( 'Page','orbit' ) . ' ' . get_query_var( 'paged' ) . ')</p></div>';
	} else {
			$after = '</p></div>';
	}

	if ( !is_front_page() 
		 || ( 'posts' == get_option( 'show_on_front' ) && is_front_page() ) ){

		if ( is_search() ) {
			echo $before; printf( __( 'Search Results for: "%s"', 'orbit' ), get_search_query() ); echo $after;

		} elseif ( is_home() ) {

			if ( isset( $GLOBALS['orbit_current_menu_title'] ) )
				echo $before . $GLOBALS['orbit_current_menu_title'] . $after;
			else
				echo $before . 'Blog' . $after;

		} elseif ( is_page() && !$post->post_parent ) {
			echo $before . get_the_title() . $after;

		} elseif ( is_page() && $post->post_parent ) {
			$parent_id	= $post->post_parent;
			$breadcrumbs = array();

			while ( $parent_id ) {
				$page = get_page( $parent_id );
				$breadcrumbs[] = '<a href="' . get_permalink( $page->ID ) . '">' . get_the_title( $page->ID ) . '</a>';
				$parent_id	= $page->post_parent;
			}
			$breadcrumbs = array_reverse( $breadcrumbs );

			echo $before;

			foreach ($breadcrumbs as $crumb)
				echo $crumb . ' ' . $chevron . ' ';
			echo get_the_title() . $after;

		} elseif ( is_single() && !is_attachment() ) {

			if ( get_post_type() != 'post' ) {
				$post_type = get_post_type_object( get_post_type() );
				$slug = $post_type->rewrite;
				echo $before . '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a> ' . $chevron . ' ' . get_the_title() . $after;

			} else {
				$cat = get_the_category(); $cat = $cat[0];
				echo $before . get_category_parents( $cat, TRUE, ' ' . $chevron . ' ' ) . get_the_title() . $after;
			}

		} elseif ( is_category() ) {
			global $wp_query;

			$cat_obj = $wp_query->get_queried_object();
			$thisCat = $cat_obj->term_id;
			$thisCat = get_category( $thisCat );
			$parentCat = get_category( $thisCat->parent );
			echo $before;
			_e( 'Category Archives: ', 'orbit' );

			if ($thisCat->parent != 0)
				echo get_category_parents( $parentCat, TRUE, ' ' . $chevron . ' ' );

			echo single_cat_title( '', false ) . $after;

		} elseif ( is_tag() ) {
			echo $before; printf( __( 'Posts tagged %s', 'orbit' ), single_tag_title( '', false ) ); echo $after;

		} elseif ( is_author() ) {
			global $author;

			$userdata = get_userdata( $author );
			echo $before; printf( __( 'All posts by %s', 'orbit' ), $userdata->display_name ); echo $after;

		} elseif ( is_404() ) {
			echo $before . __( 'Error 404 ','orbit' ) . $after;

		} elseif ( is_day() ) {
			echo $before . __( 'Daily Archives: ', 'orbit' );
			echo '<a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . get_the_time( 'Y' ) . '</a> ' . $chevron . ' ';
			echo '<a href="' . get_month_link( get_the_time( 'Y' ),get_the_time( 'm' ) ) . '">' . get_the_time( 'F' ) . '</a> ' . $chevron . ' ';
			echo get_the_time( 'd' ) . $after;

		} elseif ( is_month() ) {
			echo $before . __( 'Monthly Archives: ', 'orbit' );
			echo '<a href="' . get_year_link( get_the_time( 'Y' ) ) . '">' . get_the_time( 'Y' ) . '</a> ' . $chevron . ' ';
			echo get_the_time( 'F' ) . $after;

		} elseif ( is_year() ) {
			echo $before . __( 'Yearly Archives: ', 'orbit' );
			echo get_the_time( 'Y' ) . $after;
		}
	}
}

/**
 * Render social items
 */
function orbit_render_social_items(){
	?>
		<div class="social-icons">
			<ul>
				<?php $options = orbit_get_theme_options();

					if (!empty( $options['rss'] ) ) echo '<li><a href="' . $options['rss'] . '">'
						.'<img src="' . get_template_directory_uri() . '/images/rss-feed-icon.png" width="24" height="24" alt="RSS Feed">'
						.'</a></li>';

					if (!empty( $options['twitter'] ) ) echo '<li><a href="' . $options['twitter'] . '">'
						.'<img src="' . get_template_directory_uri() . '/images/twitter-icon.png" width="24" height="24" alt="Twitter">'
						.'</a></li>';

				   if (!empty( $options['facebook'] ) ) echo '<li><a href="' . $options['facebook'] . '">'
						.'<img src="' . get_template_directory_uri() . '/images/facebook-icon.png" width="24" height="24" alt="Facebook">'
						.'</a></li>';

					if (!empty( $options['googleplus'] ) ) echo '<li><a href="' . $options['googleplus'] . '" rel="me">'
						.'<img src="' . get_template_directory_uri() . '/images/googleplus-icon.png" width="24" height="24" alt="Google Plus">'
						.'</a></li>';

					if (!empty( $options['linkedin'] ) ) echo '<li><a href="' . $options['linkedin'] . '">'
						.'<img src="' . get_template_directory_uri() . '/images/linkedin-icon.png" width="24" height="24" alt="LinkedIn">'
						.'</a></li>';

					if (!empty( $options['youtube'] ) ) echo '<li><a href="' . $options['youtube'] . '">'
						.'<img src="' . get_template_directory_uri() . '/images/youtube-icon.png" width="24" height="24" alt="YouTube">'
						.'</a></li>';

					if (!empty( $options['vimeo'] ) ) echo '<li><a href="' . $options['vimeo'] . '">'
						.'<img src="' . get_template_directory_uri() . '/images/vimeo-icon.png" width="24" height="24" alt="Vimeo">'
						.'</a></li>';
				?>
			</ul>
		</div>
	<?php
}

/**
 * Menu custom orbit. Delete exceed class in ul list menu
 */
function orbit_custom_menu( $theme_location, $menu_classes, $ul_class, $depth ) {

	$str_classes = implode( " ", $menu_classes );
	$str_menu = wp_nav_menu( array(
		'container' => 'div',
		'container_class' => $str_classes,
		'menu_class' => $str_classes,
		'theme_location'  => $theme_location,
		'depth'			  => $depth,
		'echo' => FALSE )
	);
	$str_menu = str_replace(
		array( '" class="' . $str_classes . '">', '<ul>' ),
		array( '" class="' . $ul_class . '">', '<ul class="' . $ul_class . '">' ),
		$str_menu
	);

	echo $str_menu;
}

/**
 * Render sidebar
 */
function orbit_get_sidebar( $location ){

	$options = orbit_get_theme_options();

	if ( is_page_template( 'full-width-page.php' ) && is_front_page() ){
		return;
	}

	$sidebar = '';
	if ( is_page_template( 'page-two.php' ) ){
		$sidebar = 'two';
	}

	if ( ( $location == 'rigth' ) &&  ( $options['theme_layout'] == 'content-sidebar' ) ) {
		get_sidebar( $sidebar );
	}

	if ( ( $location == 'left' ) &&	 ( $options['theme_layout'] == 'sidebar-content' ) ) {
		get_sidebar( $sidebar );
	}
}


/**
 * Render slider in front page
 */
function orbit_render_slider(){

	$options = orbit_get_theme_options();

	if ( ( $options['slide_image_1'] == '' ) && ( $options['slide_image_1'] == '' ) && ( $options['slide_image_1'] == '' )) {
?>
	<div class="flexslider">
		<ul class="slides">
			<li>
				<img src="<?php echo get_template_directory_uri() . '/images/DefaultSlides_01.jpg'; ?>" width="500" height="325" alt="slide1">
			</li>
			<li>
				<img src="<?php echo get_template_directory_uri() . '/images/DefaultSlides_02.jpg'; ?>" width="500" height="325" alt="slide2">
			</li>
			<li>
				<img src="<?php echo get_template_directory_uri() . '/images/DefaultSlides_03.jpg'; ?>" width="500" height="325" alt="slide3">
			</li>
		</ul>
	</div>
<?php
	} else {
?>
	<div class="flexslider">
		<ul class="slides">
			<?php if ( $options['slide_image_1'] != '' ) { ?>
				<li>
					<img src="<?php echo $options['slide_image_1']; ?>" alt="slide1">
				</li>

			<?php
				 }
				 if ( $options['slide_image_2'] != '' ) {
			?>
				<li>
					<img src="<?php echo $options['slide_image_2']; ?>" alt="slide2">
				</li>
			<?php
				 }
				 if ( $options['slide_image_3'] != '' ) {
			?>
				<li>
					<img src="<?php echo $options['slide_image_3']; ?>" alt="slide3">
				</li>
			<?php } ?>
		</ul>
	</div>
<?php
	}
}
?>